#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from zope.annotation.interfaces import IAttributeAnnotatable
from zope.component.interfaces import IObjectEvent

# import packages
from zope.interface import Interface, Attribute


class ISiteRoot(IAttributeAnnotatable):
    """Marker interface for site root"""


class INewLocalSiteCreatedEvent(IObjectEvent):
    """Event interface when a new site root has been created"""


class ISiteUpgradeEvent(IObjectEvent):
    """Event interface when a site upgrade is requested"""


SITE_GENERATIONS_KEY = 'pyams.generations'


class ISiteGenerations(Interface):
    """Site generations interface"""

    generation = Attribute("Current schema generation")

    def evolve(self, site, current=None):
        """Evolve from current generation to last one"""


class IStaticConfigurationManager(IAttributeAnnotatable):
    """Static configuration manager marker interface"""


class IConfigurationManager(IAttributeAnnotatable):
    """Configuration manager marker interface"""


class IConfigurationFactory(Interface):
    """Configuration factory interface

    This factory may be loaded through an adapter
    """


class IBackOfficeConfigurationFactory(Interface):
    """Back-office configuration factory interface

    This factory may be loaded through an adapter
    """


class IOptionalUtility(Interface):
    """Marker interface for site utilities that can be removed"""
